#WRSIS-API-test.py
'''Test retrieval following the CSM example API document. '''

# requests is a module to interact with http servers
import requests

# json is to read the restricted credentials
import json

def WRSIS_download(server_IP, startDate, endDate):
    url = 'http://' + server_IP + '/WRSIS/gisapi/getUKMetSurveyData'
    cred_fn = 'Cred-WRSIS-API.json'
    date_params = {
        'fromDate':startDate,
        'toDate':endDate}

    # load credentials from restricted file
    with open(cred_fn,'r') as cred_file: 
        cred_dict = json.load(cred_file)
    
    # set up http session
    session = requests.Session()

    # provide authorisation
    # Surprisingly, this script seems to behave the same if session.auth is not provided
    #session.auth = (cred_dict['Username'], cred_dict['Password']) 

    r = session.post(url,json=date_params)

    # possible HTTP responses as provided in the API document
    # (I've seen some other responses though, e.g. 415)
    # It seems there is another layer of status codes
    status_codes = {
            200 : 'OK',
            201 : 'Created',
            202 : 'Accepted (Request accepted, and queued for execution)',
            400 : 'Bad request',
            401 : 'Authentication failure',
            403 : 'Forbidden',
            404 : 'Resource not found',
            405 : 'Method Not Allowed',
            409 : 'Conflict',
            412 : 'Precondition Failed',
            413 : 'Request Entity Too Large',
            500 : 'Internal Server Error',
            501 : 'Not Implemented',
            503 : 'Service Unavailable'}

    # checking the HTTP status code (not the code in the repsonse)
    if r.status_code == 200:
        print('HTTP request succeeded OK')

        print('Response is')
        # extract the dict from the responses
        # r.content is 'bytes' type.  Extraction depends on versions of python modules
        response = json.loads(str(r.content)[2:-1])
        print(json.dumps(response,indent=2))

    elif r.status_code in status_codes:
        print("HTTP response did not succeed OK, code is {:d}: {:s} ".format(r.status_code,status_codes[r.status_code]))

    else:
        print("HTTP response did not succeed OK, unknown code {:d}".format(r.status_code))

def WRSIS_upload(server_IP, file2upload):
    url = 'http://' + server_IP + '/WRSIS/gisapi/uploadGisZipFile'
    cred_fn = 'Cred-WRSIS-API_admin.json'
    file_param = {'files':file2upload}

    # load credentials from restricted file
    with open(cred_fn,'r') as cred_file: 
        cred_dict = json.load(cred_file)
    
    # set up http session
    session = requests.Session()

    # provide authorisation
    # Surprisingly, this script seems to behave the same if session.auth is not provided
    #session.auth = (cred_dict['Username'], cred_dict['Password']) 

    r = session.post(url,json=file_param)

    # possible HTTP responses as provided in the API document
    status_codes = {
            200 : 'OK',
            401 : 'Invalid file',
            500 : 'Unable to upload as server has down . Please try again later.'}

    # checking the HTTP status code (not the code in the repsonse)
    if r.status_code == 200:
        print('HTTP request succeeded OK')

        print('Response is')
        # extract the dict from the responses
        # r.content is 'bytes' type.  Extraction depends on versions of python modules
        response = json.loads(str(r.content)[2:-1])
        print(json.dumps(response,indent=2))

    elif r.status_code in status_codes:
        print("HTTP response did not succeed OK, code is {:d}: {:s} ".format(r.status_code,status_codes[r.status_code]))

    else:
        print("HTTP response did not succeed OK, unknown code {:d}".format(r.status_code))


#server_IP = '197.156.117.171' # MoA IP
server_IP = '164.164.122.165:8080' # CSM development IP
#server_IP = '134.164.122.165' # public IP

WRSIS_download(server_IP,'10-06-2020','22-06-2020')

WRSIS_upload(server_IP,'forcastingmap.zip')

print('Finished script')

